@@ -669,8 +669,12 @@ class Plot:
                             saved_df = pd.read_csv('saved_strategies.csv')
 
                             if not save_path in list(saved_df['path']):
+
+                                para_pop = self.para_combination.copy()
+                                para_pop.pop('df')
+
                                 df_dict = {'path': save_path,
-                                           'para_combination':str(self.para_combination),
+                                           'para_combination':str(para_pop),
                                            'initial': self.initial_capital,
                                            'net_profit_to_mdd': self.net_profit_to_mdd,
                                            'net_profit': self.net_profit,
